@@ -26,7 +26,7 @@ from octaviaclient.tests.unit.osc.v2 import fakes
 class TestAvailabilityzoneProfile(fakes.TestOctaviaClient):
 
     def setUp(self):
-        super(TestAvailabilityzoneProfile, self).setUp()
+        super().setUp()
 
         self._availabilityzoneprofile = fakes.createFakeResource(
             'availability_zone_profile')
@@ -45,7 +45,7 @@ class TestAvailabilityzoneProfile(fakes.TestOctaviaClient):
 class TestAvailabilityzoneProfileList(TestAvailabilityzoneProfile):
 
     def setUp(self):
-        super(TestAvailabilityzoneProfileList, self).setUp()
+        super().setUp()
         self.datalist = (tuple(
             attr_consts.AVAILABILITY_ZONE_PROFILE_ATTRS[k]
             for k in self.columns),)
@@ -79,7 +79,7 @@ class TestAvailabilityzoneProfileList(TestAvailabilityzoneProfile):
 class TestAvailabilityzoneProfileDelete(TestAvailabilityzoneProfile):
 
     def setUp(self):
-        super(TestAvailabilityzoneProfileDelete, self).setUp()
+        super().setUp()
         self.cmd = availabilityzoneprofile.DeleteAvailabilityzoneProfile(
             self.app, None)
 
@@ -99,6 +99,8 @@ class TestAvailabilityzoneProfileDelete(TestAvailabilityzoneProfile):
         verifylist = [
             ('availabilityzoneprofile', 'unknown_availabilityzoneprofile')
         ]
+        self.api_mock.availabilityzoneprofile_list.return_value = {
+            'availability_zone_profiles': []}
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
         self.assertRaises(exceptions.CommandError, self.cmd.take_action,
                           parsed_args)
@@ -108,7 +110,7 @@ class TestAvailabilityzoneProfileDelete(TestAvailabilityzoneProfile):
 class TestAvailabilityzoneProfileCreate(TestAvailabilityzoneProfile):
 
     def setUp(self):
-        super(TestAvailabilityzoneProfileCreate, self).setUp()
+        super().setUp()
         self.api_mock.availabilityzoneprofile_create.return_value = {
             'availability_zone_profile': self.availabilityzoneprofile_info}
         lb_client = self.app.client_manager
@@ -140,7 +142,7 @@ class TestAvailabilityzoneProfileCreate(TestAvailabilityzoneProfile):
 class TestAvailabilityzoneProfileShow(TestAvailabilityzoneProfile):
 
     def setUp(self):
-        super(TestAvailabilityzoneProfileShow, self).setUp()
+        super().setUp()
         mock_show = self.api_mock.availabilityzoneprofile_show
         mock_show.return_value = self.availabilityzoneprofile_info
         lb_client = self.app.client_manager
@@ -164,7 +166,7 @@ class TestAvailabilityzoneProfileShow(TestAvailabilityzoneProfile):
 class TestAvailabilityzoneProfileSet(TestAvailabilityzoneProfile):
 
     def setUp(self):
-        super(TestAvailabilityzoneProfileSet, self).setUp()
+        super().setUp()
         self.cmd = availabilityzoneprofile.SetAvailabilityzoneProfile(
             self.app, None)
 
@@ -182,3 +184,18 @@ class TestAvailabilityzoneProfileSet(TestAvailabilityzoneProfile):
                 'availability_zone_profile': {
                     'name': 'new_name'
                 }})
+
+        arglist = [self._availabilityzoneprofile.id,
+                   '--availability-zone-data', '{"key1": "value1"}']
+        verifylist = [
+            ('availabilityzoneprofile', self._availabilityzoneprofile.id),
+            ('availability_zone_data', '{"key1": "value1"}'),
+        ]
+
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+        self.cmd.take_action(parsed_args)
+        self.api_mock.availabilityzoneprofile_set.assert_called_with(
+            self._availabilityzoneprofile.id, json={
+                'availability_zone_profile': {
+                    'availability_zone_data': '{"key1": "value1"}'
+                }})
